Number

Enum Number 

pub enum Number {
    Integer(i128),
    Float(f64),
}
Simpler representation of numbers so operations are simpler to handle Also can be used for custom filters/tests/fn when you want to ensure you get a number

Variants



Integer(i128)

Integers are stored in i128, which means we can’t use numbers from u128 above i128::MAX for math, which is probably ok for a template engine.



Float(f64)

Implementations

Source

impl Number

pub fn is_float(&self) -> bool

Is the number a float?

pub fn is_integer(&self) -> bool

Is the number an integer? Does not check whether the float could be converted to an integer losslessly, just checks the type.

pub fn as_float(&self) -> f64

Converts a number to a float.

pub fn as_integer(&self) -> Option<i128>

Tries to convert a number to a i128.