State

Struct State 

pub struct State<'tera> { /* private fields */ }
The state of the interpreter. We pass it around rather than put it on the VM to avoid multiple borrow issues when dealing with inheritance.

Implementations

Source

impl<'t> State<'t>

pub fn new(context: &'t Context) -> Self

Creates a new state from a Context. Public since it’s needed to test filters/fns/tests.

pub fn get<T>(&self, name: &str) -> TeraResult<Option<T>>
where for<'a> T: ArgFromValue<'a, Output = T>,

Get a variable from the context by name and convert it to the specified type.

Returns Ok(None) if the variable is not defined (undefined). Returns an error if the variable exists but cannot be converted to the target type.

pub fn call_filter( &self, name: &str, value: &Value, kwargs: Kwargs, ) -> TeraResult<Value>

Call a filter by name. Used by filters like map that need to apply other filters.